@@ -152,12 +152,6 @@ namespace xt
         using container_iterator = typename std::decay_t<CD>::iterator;
         using const_container_iterator = typename std::decay_t<CD>::const_iterator;
 
-        container_iterator data_xbegin() noexcept;
-        const_container_iterator data_xbegin() const noexcept;
-
-        container_iterator data_xend(layout_type l) noexcept;
-        const_container_iterator data_xend(layout_type l) const noexcept;
-
         underlying_container_type& data() noexcept;
         const underlying_container_type& data() const noexcept;
 
@@ -166,8 +160,18 @@ namespace xt
 
         size_type raw_data_offset() const noexcept;
 
+    protected:
+
+        container_iterator data_xbegin() noexcept;
+        const_container_iterator data_xbegin() const noexcept;
+        container_iterator data_xend(layout_type l) noexcept;
+        const_container_iterator data_xend(layout_type l) const noexcept;
+
     private:
 
+        template <class C>
+        friend class xstepper;
+
         template <class It>
         It data_xbegin_impl(It begin) const noexcept;
 
@@ -396,7 +400,7 @@ namespace xt
      * Returns a reference to the element at the specified position in the xstrided_view.
      * @param first iterator starting the sequence of indices
      * @param last iterator ending the sequence of indices
-     * The number of indices in the squence should be equal to or greater than the the number
+     * The number of indices in the sequence should be equal to or greater than the the number
      * of dimensions of the container..
      */
     template <class CT, class S, class CD>
@@ -555,7 +559,7 @@ namespace xt
         template <class E, class S>
         inline auto transpose_impl(E&& e, S&& permutation, check_policy::none)
         {
-            if (container_size(permutation) != e.dimension())
+            if (sequence_size(permutation) != e.dimension())
             {
                 throw transpose_error("Permutation does not have the same size as shape");
             }
@@ -586,9 +590,9 @@ namespace xt
         inline auto transpose_impl(E&& e, S&& permutation, check_policy::full)
         {
             // check if axis appears twice in permutation
-            for (std::size_t i = 0; i < container_size(permutation); ++i)
+            for (std::size_t i = 0; i < sequence_size(permutation); ++i)
             {
-                for (std::size_t j = i + 1; j < container_size(permutation); ++j)
+                for (std::size_t j = i + 1; j < sequence_size(permutation); ++j)
                 {
                     if (permutation[i] == permutation[j])
                     {
